<?php

/**
 * Weclome Page Class
 *
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Analytify_Welcome Class
 *
 * A general class for Welcome pages.
 *
 */

class Analytify_Welcome {

	/**
	 * @var string The capability users should have to view the page
	 */
	public $minimum_capability = 'manage_options';

	/**
	 * Get things initialized
	 *
	 * @since 1.1
	 */
	public function __construct() {

		add_action( 'admin_menu', array( $this, 'admin_menus') );
		add_action( 'admin_head', array( $this, 'admin_head' ) );
		add_action( 'admin_init', array( $this, 'welcome'    ) );
	}

	/**
	 * Register the Dashboard Pages which are later hidden but these pages
	 * are used to render the Welcome and Credits pages.
	 *
	 * @access public
	 * @since 1.1
	 * @return void
	 */
	public function admin_menus() {

		// What's new Page
		add_dashboard_page(
			__( 'Welcome to Analytify', 'wp-analytify' ),
			__( 'Welcome to Analytify', 'wp-analytify' ),
			$this->minimum_capability,
			'wp-analytify-new',
			array( $this, 'new_screen' )
		);

		// Getting Started Page
		add_dashboard_page(
			__( 'Getting started with Analytify', 'wp-analytify' ),
			__( 'Getting started with Analytify', 'wp-analytify' ),
			$this->minimum_capability,
			'wp-analytify-getting-started',
			array( $this, 'getting_started_screen' )
		);

		// Credits Page
		add_dashboard_page(
			__( 'The people that build Analytify', 'wp-analytify' ),
			__( 'The people that build Analytify', 'wp-analytify' ),
			$this->minimum_capability,
			'wp-analytify-credits',
			array( $this, 'credits_screen' )
		);
	}

	/**
	 * Hide Individual Dashboard Pages
	 *
	 * @access public
	 * @since 1.1
	 * @return void
	 */
	public function admin_head() {
		
		remove_submenu_page( 'index.php', 'wp-analytify-new' );
		remove_submenu_page( 'index.php', 'wp-analytify-getting-started' );
		remove_submenu_page( 'index.php', 'wp-analytify-credits' );

		// Badge for welcome page
		//$badge_url =  . 'images/welcome/welcome.png';
		?>
		<style type="text/css" media="screen">
		/*<![CDATA[*/
		.wp-analytify-badge {
			height: 250px;
			width: 200px;
			margin: -12px -5px;
			background: url("<?php echo plugins_url('images/welcome/welcome-analytify.png',__FILE__); ?>") no-repeat;
		}

		.about-wrap .wp-analytify-badge {
			position: absolute;
			top: 0;
			right: 0;
		}

		.wp-analytify-welcome-screenshots {
			float: right;
			margin-left: 10px !important;
			border:1px solid #ccc;
			padding:0;
			box-shadow:4px 4px 0px rgba(0,0,0,.05)
		}

		.about-wrap .feature-section {
			margin-top: 20px;
		}

		.analytify-welcome-settings{
			clear: both;
			padding-top: 20px;
		}
		/*]]>*/
		</style>
		<?php
	}

	/**
	 * Navigation tabs
	 *
	 * @access public
	 * @since 1.1
	 * @return void
	 */
	public function tabs() {
		$selected = isset( $_GET['page'] ) ? $_GET['page'] : 'wp-analytify-new';
		?>
		<h2 class="nav-tab-wrapper">
			<a class="nav-tab <?php echo $selected == 'wp-analytify-new' ? 'nav-tab-active' : ''; ?>" href="<?php echo esc_url( admin_url( add_query_arg( array( 'page' => 'wp-analytify-new' ), 'index.php' ) ) ); ?>">
				<?php _e( "What's New", 'wp-analytify' ); ?>
			</a>
			<a class="nav-tab <?php echo $selected == 'wp-analytify-getting-started' ? 'nav-tab-active' : ''; ?>" href="<?php echo esc_url( admin_url( add_query_arg( array( 'page' => 'wp-analytify-getting-started' ), 'index.php' ) ) ); ?>">
				<?php _e( 'Getting Started', 'wp-analytify' ); ?>
			</a>
			<a class="nav-tab <?php echo $selected == 'wp-analytify-credits' ? 'nav-tab-active' : ''; ?>" href="<?php echo esc_url( admin_url( add_query_arg( array( 'page' => 'wp-analytify-credits' ), 'index.php' ) ) ); ?>">
				<?php _e( 'Credits', 'wp-analytify' ); ?>
			</a>
		</h2>
		<?php
	}

	/**
	 * Render What's New Screen
	 *
	 * @access public
	 * @since 1.1
	 * @return void
	 */
	public function new_screen() {

		$display_version = ANALYTIFY_VERSION;

		?>
		<div class="wrap about-wrap">
			<h1><?php printf( __( 'Welcome to Analytify %s', 'wp-analytify' ), $display_version ); ?></h1>
			<div class="about-text"><?php printf( __( '<em>Thank you for updating to the latest version!</em> <br /> Analytify %s is ready to make people lives easier for those who love Google Analytics and WordPress. It makes Analytics simple for WordPress users that everyone can understand about their Website statistics and behavior. ', 'wp-analytify' ), $display_version ); ?></div>
			<div class="wp-analytify-badge"></div>

			<?php $this->tabs(); ?>

			<div class="newfeatures">
				<h3><?php _e( 'New features', 'wp-analytify' );?></h3>

				<div class="feature-section">

					  <img src="<?php echo plugins_url('wp-analytify/images/welcome/analytify-shortcodes-dropdown.png'); ?>" class="wp-analytify-welcome-screenshots"/> 

					<h4><?php _e( 'Analytify Shortcodes', 'wp-analytify' );?></h4>	
					<p><?php print( __( 'Analytify shortcodes can be used for multiple purposes. It gives you more flexibility than the front-end statistics. You can disable front-end stats and use these shortcodes in any of your pages/posts to show Analytics in tabular style. If you are familiar with CSS, It can be easily modified to match with your website look and feel. <br / > <br / > Follwing are two types of shortcodes:', 'wp-analytify' )); ?></p>

					<h4><?php _e( 'a) Simple:', 'wp-analytify' );?></h4>	
					<p><?php print( __( 'Simple Analytify shortcode returns you only the numbers i.e results. It is useful when you want results of only 1 Metrics and can apply permissions using roles. You can fetch numbers of <em>Sessions, Pageviews, Bounce rate and Users</em> etc', 'wp-analytify' ) ); ?></p>

					<h4><?php _e( 'b) Advanced:', 'wp-analytify' );?></h4>
					<p><?php  _e( 'With this Advanced option, You can choose <em>more than 1 Metrics and Dimensions, Sort the results, get maximum rows, apply permissions and fetch Analytics with specified start-date and end-date</em>. Advanced shortcode returns results in table form which can be styled according to your website.', 'wp-analytify' );?></p>

				</div>
			</div>
	
			<div class="newfeatures">
					 <img src="<?php echo plugins_url('wp-analytify/images/welcome/authenticate2.png'); ?>" class="wp-analytify-welcome-screenshots"/> 
				<h3><?php _e( 'Front-end Statistics', 'wp-analytify' );?></h3>
				<p><?php _e( 'In version 1.1, We have introduced the <em>New Front-end Analytics</em> which will fetch the stats like backend but with an awesome UI for front-end stats. It was a long awaited feature which was under development since 1.0 but finally It is here. It can be customized (if you are good at CSS) according to your website look and fool. <br /><br /> Following are it\'s important options: ', 'wp-analytify'); ?></p>
		
				<div  style="clear:both" class="feature-section col three-col">
					<div>
		
						<h4><?php _e( 'Disable front-end', 'wp-analytify' );?></h4>
						<p><?php _e( 'We introduced the ability to disable the front-end stats on the full site. Check it, if you don\'t want to load Analytics at all. Remember, you can use Shortcodes still.', 'wp-analytify' );?></p>

						<h4><?php _e( 'Display Analytics to Users', 'wp-analytify' );?></h4>
						<p><?php _e( 'Show <em>front-end</em> Analytics to selected user roles only.', 'wp-analytify' );?></p>
					</div>

					<div>
						<h4><?php _e( 'Analytics on Post types', 'wp-analytify' );?></h4>
						<p><?php _e( 'Show Analytics under the selected post types only. You can select your custom post types as well.' ,'wp-analytify' );?></p>

						<h4><?php _e( 'Front-end Analytics panels', 'wp-analytify' );?></h4>
						<p><?php _e( 'Select which Stats panels you want to display at front-end. We recommend to use upto 8 Panels for better page speed.', 'wp-analytify' );?></p>
					</div>

					<div class="last-feature">
						<h4><?php _e( 'Exclude Analytics on specific pages', 'wp-analytify' );?></h4>
						<p><?php _e( 'Select posts or pages on which you don\'t want to show Analytics.', 'wp-analytify' );?></p>
					</div>
				</div>
			</div>

			

			<div class="analytify-welcome-settings">
				<a href="<?php echo esc_url( admin_url( 'admin.php?page=analytify-settings') ); ?>"><?php _e( 'Go to Analytify Settings', 'wp-analytify' ); ?></a> &middot;
				<a href="http://wp-analytify.com/changelog/" target="_blank"><?php _e( 'View the Full Changelog', 'wp-analytify' ); ?></a>
			</div>
		</div>
		<?php
	}

	/**
	 * Render Getting Started Screen
	 *
	 * @access public
	 * @since 1.1
	 * @return void
	 */

	public function getting_started_screen() {
		
		$display_version = ANALYTIFY_VERSION;
		?>

		<div class="wrap about-wrap">
			<h1><?php printf( __( 'Welcome to Analytify %s', 'wp-analytify' ), $display_version ); ?></h1>
			<div class="about-text"><?php printf( __( '<em>Thank you for updating to the latest version!</em> <br /> Analytify %s is ready to make people lives easier for those who love Google Analytics and WordPress. It makes Analytics simple for WordPress users that everyone can understand about their Website statistics and behavior. ', 'wp-analytify' ), $display_version ); ?></div>
			<div class="wp-analytify-badge"></div>

			<?php $this->tabs(); ?>

			<p class="about-description"><?php _e( 'Getting started with Analytify plugin settings are very easy to use and ready to go in minutes. If there is something you don\'t understand or confusing, do ask us on our Support <a href="http://wpbrigade.com/forums/" tagget="_blank">forums</a> without hesitation.', 'wp-analytify' ); ?></p>

			<div class="changelog">
				<h3><?php _e( 'Connect with Analytify', 'wp-analytify' );?></h3>

				<div class="feature-section">
				 <img src="<?php echo plugins_url('images/welcome/authenticate2.png',__FILE__);?>" alt="" class="wp-analytify-welcome-screenshots">  
					
					<h4><?php _e( 'Authentication', 'wp-analytify' );?></h4>
					<p><?php _e( 'You must have Google Analytics account and setup your website profiles to use with Analytify on your WordPress based sites. If you have GA account ID and website profiles, Click on Authenticate link under the Authentication Tab. A popup will appear where you will need to sign-in using your Analytics ID. It will take you to a next step where you will be give a code, Simply copy that code and paste it in Input given. Click on Save Changes and Analytify will be connected to GA for fetching Analytics. <br /> <br />This <a href="https://www.screenr.com/UmmN" target="_blank">video</a> gives you better understanding of configuring the plugin.', 'wp-analytify' );?></p>

				</div>
			</div>

			

			<div class="changelog">
				<h3><?php _e( 'Setting up profiles', 'wp-analytify' );?></h3>

				<div class="feature-section">
						<img src="<?php echo plugins_url('images/welcome/profile-data.png',__FILE__);?>" alt="" class="wp-analytify-welcome-screenshots"> 
					<h4><?php _e( 'Profile Tab', 'wp-analytify' );?></h4>
					<p><?php _e( 'This tab section consists of many important settings. After Authentication, Setup your profiles here. All of the options are easy to understand.', 'wp-analytify' );?></p>

					<h5><?php _e( 'a) Install Google Analytics tracking code', 'wp-analytify' );?></h5>
					<p><?php _e( 'First, you need to check if you want to install Google Analytics tracking code by Analytify or uncheck it if you have already installed it manually or via some other way. ');?></p>

					<h5><?php _e( 'b) Exclude users from tracking', 'wp-analytify' );?></h5>
					<p><?php _e( 'Usually Administrators don\'t want to track themselves. So, this option can be commonly used if you want to exclude your special users from tracking data.');?></p>

					<h5><?php _e( 'c) Tracking code type', 'wp-analytify' );?></h5>
					<p><?php _e( 'Google recommends to use Analytics.js (Universal Tracking) now. So, we recommend to use this option.');?></p>

					<h5><?php _e( 'd) Profile for posts (Backend/Front-end)', 'wp-analytify' );?></h5>
					<p><?php _e( 'Select your website profile for wp-admin edit pages and fron-end pages. Select profile which matches your current WordPress website.');?></p>

					<h5><?php _e( 'e) Profile for Dashboard', 'wp-analytify' );?></h5>
					<p><?php _e( 'Select your website profile for Dashboard Stats. You can select your any Website profile. It will show Analytics for your selected website profile.');?></p>

				</div>
			</div>

			<div class="changelog">
				<h3><?php _e( 'Display Statistics at front-end pages', 'wp-analytify' );?></h3>

				<div class="feature-section col three-col">
					
					<img src="<?php echo plugins_url('images/welcome/front-end.png',__FILE__);?>" alt="" class="wp-analytify-welcome-screenshots">  
					
					<h4><?php _e( 'Front Tab', 'wp-analytify' );?></h4>
					<p><?php _e( 'In version 1.1, We have introduced the <em>New Front-end Analytics</em> which will fetch the stats like backend but with an awesome UI for front-end stats. It was a long awaited feature which was under development since 1.0 but finally It is here. It can be customized (if you are good at CSS) according to your website look and fool. <br /><br /> Following are it\'s important options: ', 'wp-analytify'); ?></p>

					<div style="clear:both;">		
						<h4><?php _e( 'Disable front-end', 'wp-analytify' );?></h4>
						<p><?php _e( 'We introduced the ability to disable the front-end stats on the full site. Check it, if you don\'t want to load Analytics at all. Remember, you can use Shortcodes still.', 'wp-analytify' );?></p>

						<h4><?php _e( 'Display Analytics to Users', 'wp-analytify' );?></h4>
						<p><?php _e( 'Show <em>front-end</em> Analytics to selected user roles only.', 'wp-analytify' );?></p>
					</div>

					<div>
						<h4><?php _e( 'Analytics on Post types', 'wp-analytify' );?></h4>
						<p><?php _e( 'Show Analytics under the selected post types only. You can select your custom post types as well.' ,'wp-analytify' );?></p>

						<h4><?php _e( 'Front-end Analytics panels', 'wp-analytify' );?></h4>
						<p><?php _e( 'Select which Stats panels you want to display at front-end. We recommend to use upto 8 Panels for better page speed.', 'wp-analytify' );?></p>
					</div>

					<div class="last-feature">
						<h4><?php _e( 'Exclude Analytics on specific pages', 'wp-analytify' );?></h4>
						<p><?php _e( 'Select posts or pages on which you don\'t want to show Analytics.', 'wp-analytify' );?></p>
					</div>
				</div>
			</div>

			<div class="changelog">
				<h3><?php _e( 'Display Statistics under Edit pages (backend)', 'wp-analytify' );?></h3>

				<div class="feature-section col three-col">
					
					<img src="<?php echo plugins_url('images/welcome/admin-end.png',__FILE__);?>" alt="" class="wp-analytify-welcome-screenshots"> 

					<h4><?php _e( 'Admin Tab', 'wp-analytify' );?></h4>
					<p><?php _e( 'Admin tab section is to manage the Analytics panels under EDIT screen of post/pages in wp-admin.', 'wp-analytify' );?></p>


					<div style="clear:both">
						<h4><?php _e( 'Disable Analytics under posts/pages.', 'wp-analytify' );?></h4>
						<p><?php _e( 'Check it, If you don\'t want to load Stats by default on all pages. If you disable it, you can still fetch the stats under each post/page on single click.', 'wp-analytify' );?></p>

						<h4><?php _e( 'Display Analytics to Users', 'wp-analytify' );?></h4>
						<p><?php _e( 'Show <em>Google</em> Analytics to selected user roles only.', 'wp-analytify' );?></p>
					</div>

					<div>
						<h4><?php _e( 'Analytics on Post types', 'wp-analytify' );?></h4>
						<p><?php _e( 'Show Analytics under the selected post types only. You can select your custom post types as well.' ,'wp-analytify' );?></p>

						<h4><?php _e( 'Edit pages/posts Analytics panels', 'wp-analytify' );?></h4>
						<p><?php _e( 'Select which Stats panels you want to display at backend. We recommend to use upto 10 Panels for better page speed.', 'wp-analytify' );?></p>
					</div>

					<div class="last-feature">
						<h4><?php _e( 'Exclude Analytics on specific pages', 'wp-analytify' );?></h4>
						<p><?php _e( 'Select posts or pages on which you don\'t want to show Analytics.', 'wp-analytify' );?></p>
					</div>

				</div>
			</div>

			<div class="changelog">
				<h3><?php _e( 'Licensing', 'wp-analytify' );?></h3>

				<div class="feature-section">
					<p><?php _e( 'We have a year based pricing model as we think this is the best model to keep our normal lives easier and down the costs of support servers etc. You need a valid license key if you want to get support and updates in the future for a year. After a year, you will get discount to renew your license. ', 'wp-analytify' );?></p>
				</div>
			</div>

		</div>
		<?php
	}

	/**
	 * Render Credits Screen
	 *
	 * @access public
	 * @since 1.1
	 * @return void
	 */
	public function credits_screen() {
		list( $display_version ) = explode( '-', ANALYTIFY_VERSION );
		?>
		<div class="wrap about-wrap">
			<h1><?php printf( __( 'Welcome to Analytify %s', 'wp-analytify' ), $display_version ); ?></h1>
			<div class="about-text"><?php printf( __( '<em>Thank you for updating to the latest version!</em> <br /> Analytify %s is ready to make people lives easier for those who love Google Analytics and WordPress. It makes Analytics simple for WordPress users that everyone can understand about their Website statistics and behavior. ', 'wp-analytify' ), $display_version ); ?></div>
			<div class="wp-analytify-badge"></div>

			<?php $this->tabs(); ?>

			<p class="about-description"><?php _e( 'Analytify is developed by <a href="http://wpbrigade.com/">WPBrigade</a> i.e brigade of WordPress developers.', 'wp-analytify' ); ?></p>
		</div>
		<?php
	}

	/**
	 * Sends user to the Welcome page on first activation of Analytify as well as each
	 * time Analytify is upgraded to a new version
	 *
	 * @access public
	 * @since 1.1
	 * @return void
	 */
	public function welcome() {
		
		$is_show = get_option( 'show_welcome_page' );

		if( $is_show == 0 ) { // First time install

			update_option( 'show_welcome_page' ,  1 );
			wp_redirect( admin_url( 'index.php?page=wp-analytify-getting-started' ) ); 

		}
	}
}
new Analytify_Welcome();